:mod:`ctd`
----------

.. automodule:: ctd.read
   :members:
   :undoc-members:
   :show-inheritance:


:mod:`processing`
-----------------

.. automodule:: ctd.processing
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`plotting`
---------------

.. automodule:: ctd.plotting
   :members:
   :undoc-members:
   :show-inheritance:
